@@ -80,12 +80,12 @@ class Game : public GameObject
 		const std::string bgColor() { return m_bgColor; }
 		int houses() { return m_houses; }
 		int hotels() { return m_hotels; }
-		const bool isValid() { return m_isValid; }
+		bool isValid() { return m_isValid; }
 
 		bool sendChildXMLUpdate(Player *pOutput, bool emptyUpdate);
 		void unsetChildProperties();
 
-		unsigned int players();
+		int players();
 		unsigned int connectedPlayers();
 		Player *addPlayer(Player *, const bool &isMaster = false, const bool &isSpectator = false);
 		Player *findPlayer(int playerId);
@@ -123,7 +123,7 @@ class Game : public GameObject
 
 		void newTrade(Player *pInput, unsigned int playerId);
 		Trade *findTrade(Player *player);
-		Trade *findTrade(unsigned int tradeId);
+		Trade *findTrade(int tradeId);
 		void delTrade(Trade *trade);
 		void acceptTrade(Player *pInput, char *);
 		void rejectTrade(Player *pInput, unsigned int tradeId);
@@ -139,7 +139,7 @@ class Game : public GameObject
 		Estate *findNextJailEstate(Estate *startEstate = NULL);
 		unsigned int estates() const { return m_estates.size(); }
 		void setPausedForDialog(const bool paused);
-		const bool pausedForDialog();
+		bool pausedForDialog();
 		void delEstate(Estate *);
 		void transferEstate(Estate *estate, Player *player, const bool verbose = false);
 		CardGroup *newCardGroup(const std::string name);
