@@ -18,21 +18,35 @@
 #include <signal.h>
 #include <syslog.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #include <iostream>
 #include <string>
 
-#include <libcapsinetwork/listener.h>
-#include <libcapsinetwork/socket.h>
-
-#include "const.h"
+#include "config.h"
+#include "listener.h"
+#include "socket.h"
 #include "main.h"
 #include "server.h"
 
+#if USE_SYSTEMD_DAEMON
+#include <systemd/sd-daemon.h>
+#endif /* USE_SYSTEMD_DAEMON */
+
 MonopdListener::MonopdListener( MonopdServer *server )
  :	Listener(),
  	m_server( server )
 {
+#if USE_SYSTEMD_DAEMON
+	int socket_count = sd_listen_fds(0);
+	if (socket_count > 0) {
+		for (int fd = SD_LISTEN_FDS_START; socket_count--; fd++) {
+			addListenFd(fd);
+		}
+		syslog( LOG_NOTICE, "listener: systemd");
+	} else
+#endif /* USE_SYSTEMD_DAEMON */
+
 	if ( addListenPort( server->port() ) == -1 )
 	{
 		syslog( LOG_ERR, "could not bind port %d, exiting", server->port() );
@@ -48,7 +62,7 @@ void MonopdListener::socketHandler( Socket *socket, const std::string &data )
 	{
 		case Socket::New:
 			syslog( LOG_INFO, "connection: fd=[%d], ip=[%s]", socket->fd(), socket->ipAddr().c_str() );
-			socket->ioWrite( std::string("<monopd><server version=\"") + MONOPD_VERSION_STRING + "\"/></monopd>\n" );
+			socket->ioWrite( std::string("<monopd><server version=\"") + VERSION + "\"/></monopd>\n" );
 			m_server->initSocketTimeoutEvent( socket->fd() );
 			break;
 
@@ -57,7 +71,7 @@ void MonopdListener::socketHandler( Socket *socket, const std::string &data )
 			syslog( LOG_INFO, "disconnect: fd=[%d], ip=[%s]", socket->fd(), socket->ipAddr().c_str() );
 			m_server->closedSocket( socket );
 			break;
-			
+
 		case Socket::Ok:
 			m_server->processInput( socket, data );
 			break;
@@ -70,7 +84,7 @@ int main(int argc, char **argv)
 	signal( SIGPIPE, SIG_IGN );
 
 	openlog( "monopd", LOG_PID, LOG_DAEMON );
-	syslog( LOG_NOTICE, "monopd %s started", MONOPD_VERSION_STRING );
+	syslog( LOG_NOTICE, "monopd %s started", VERSION );
 
 	MonopdServer *server = new MonopdServer();
 	if ( argc > 1 )
@@ -83,6 +97,9 @@ int main(int argc, char **argv)
 
 	server->initMonopigatorEvent();
 
+	/* Indicate to systemd that we are ready to answer requests. */
+	server->updateSystemdStatus();
+
 	for(;;)
 	{
 		// Check for network events
