@@ -18,11 +18,11 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <string>
 
-#include <libcapsinetwork/socket.h>
-
+#include "socket.h"
 #include "card.h"
 #include "display.h"
 #include "estate.h"
@@ -119,7 +119,7 @@ void Player::ioInfo(const char *data, ...)
 {
 	va_list arg;
 	char buf[2048];
-	
+
 	va_start(arg, data);
 	vsnprintf(buf, sizeof(buf)-1, data, arg);
 	va_end(arg);
@@ -137,7 +137,7 @@ void Player::ioError(const char *data, ...)
 {
 	va_list arg;
 	char buf[2048];
-	
+
 	va_start(arg, data);
 	vsnprintf(buf, sizeof(buf)-1, data, arg);
 	va_end(arg);
@@ -169,7 +169,7 @@ void Player::setDisplay(Estate *estate, const char *data, ...)
 {
 	va_list arg;
 	char buf[2048];
-	
+
 	va_start(arg, data);
 	vsnprintf(buf, sizeof(buf)-1, data, arg);
 	va_end(arg);
@@ -314,7 +314,7 @@ void Player::endTurn(bool userRequest)
 	else if (getBoolProperty("canrollagain"))
 	{
 		m_game->setDisplay(m_estate, false, false, "%s may roll again.", getStringProperty("name").c_str());
-		
+
 		setBoolProperty("can_roll", true);
 		setBoolProperty("canrollagain", false);
 		return;
@@ -331,7 +331,7 @@ void Player::endTurn(bool userRequest)
 			ioError("You cannot end your turn while jailed.");
 		return;
 	}
-	
+
 	else if (m_game->pausedForDialog())
 	{
 		if (userRequest)
@@ -442,7 +442,7 @@ void Player::buyEstate()
 
 	if (!payMoney(m_estate->price()))
 	{
-		ioError("You do not have enough money to buy this property, %s costs %d.", m_estate->getStringProperty("name").c_str(), m_estate->price());
+		ioError("You do not have enough money to buy this property, %s costs %d.", m_estate->name().c_str(), m_estate->price());
 		return;
 	}
 
@@ -484,7 +484,7 @@ void Player::sellEstate(int estateId)
 	int sellPrice = estate->price() / 2;
 
 	addMoney(sellPrice);
-	m_game->transferEstate(m_estate, 0);
+	m_game->transferEstate(estate, 0);
 	m_game->setDisplay(estate, false, false, "%s sold %s for %d.", getStringProperty("name").c_str(), estate->getStringProperty("name").c_str(), sellPrice);
 
 	if (getBoolProperty("hasdebt"))
@@ -601,7 +601,7 @@ void Player::buyHouse(int estateId)
 		ioError("You already have a hotel on '" + estate->name() + "'.");
 		return;
 	}
-	else if (estate->getIntProperty("houses") >= estate->maxHouses()) 
+	else if (estate->getIntProperty("houses") >= estate->maxHouses())
 	{
 		ioError("The even build rule prevents you from building more house on '" + estate->name() + "'.");
 		return;
@@ -813,7 +813,7 @@ void Player::updateTradeMoney(char *data)
 	}
 
 	int playerToId = atoi(strsep(&data, ":"));
-	unsigned int money = atoi(data);
+	int money = atoi(data);
 
 	Trade *trade = m_game->findTrade(tradeId);
 	if (!trade)
@@ -861,7 +861,7 @@ void Player::advance(int pos, bool direct)
 {
 	int estates = m_game->estates();
 	int location = m_estate ? m_estate->id() : 0;
-	
+
 	location += pos;
 	if (location >= estates)
 		location %= estates;
@@ -901,7 +901,7 @@ void Player::addMoney(int amount)
 	setProperty("money", getIntProperty("money") + amount);
 }
 
-bool Player::payMoney(unsigned int amount)
+bool Player::payMoney(int amount)
 {
 	int money = getIntProperty("money");
 	if (money < amount)
@@ -1016,7 +1016,7 @@ void Player::takeCard(Card *card)
 		}
 }
 
-Card *Player::findCard(unsigned int cardId)
+Card *Player::findCard(int cardId)
 {
 	Card *card = 0;
 	for(std::vector<Card *>::iterator it = m_cards.begin() ; it != m_cards.end() && (card = *it) ; ++it)
@@ -1034,7 +1034,7 @@ Card *Player::findOutOfJailCard()
 	return 0;
 }
 
-unsigned int Player::assets()
+int Player::assets()
 {
 	if (m_game)
 		return m_game->playerAssets(this);
