@@ -47,6 +47,7 @@ public:
 	void initSocketTimeoutEvent(int socketFd);
 	int processEvents(); /* returns -1 or socket fd in case of socket timeout */
 	void processInput(Socket *socket, const std::string data);
+	void updateSystemdStatus();
 
 private:
 	Event *newEvent(unsigned int eventType, Game *game = 0, int id = 0);
@@ -54,7 +55,7 @@ private:
 	Event *findEvent(Game *game, unsigned int eventType);
 	Event *findEvent(Game *game, GameObject *object);
 	void delEvent(Event *event);
-	Game *findGame(unsigned int gameId);
+	Game *findGame(int gameId);
 	GameConfig *newGameConfig(const std::string id, const std::string name, const std::string description);
 	void delGameConfig(GameConfig *gameConfig);
 	Player *findPlayer(int playerId);
